//
//  OpenPlatformActionView.m
//  OpenSDKDemo_Example
//
//  Created by Jiny.du on 2019/7/22.
//  Copyright © 2019 bytedance.co All rights reserved.
//

#import "OpenPlatformActionView.h"
#import "OpenPlatformUIDefine.h"
#import <Masonry/Masonry.h>

@interface OpenPlatformActionView ()

@property (nonatomic, strong) NSMutableArray<UIButton *> *buttonArray;

@end

@implementation OpenPlatformActionView

#pragma mark - life cycle

- (instancetype)initWithNumberOfButtons:(NSInteger)numberOfButtons
{
    self = [super init];
    if (self) {
        _buttonArray = [[NSMutableArray alloc] initWithCapacity:numberOfButtons];
        for (int i = 0; i < numberOfButtons; i++) {
            UIButton *button = [UIButton buttonWithType:UIButtonTypeCustom];
            button.layer.cornerRadius = 6;
            button.clipsToBounds = YES;
            [_buttonArray addObject:button];
        }
        [self p_setupUI];
        [self p_setupConstraints];
    }
    return self;
}

#pragma mark - Public

- (UIButton *)buttonAtIndex:(NSInteger)index
{
    if (index < 0 || index >= self.buttonArray.count) {
        return nil;
    }

    return [self.buttonArray objectAtIndex:index];
}

#pragma mark - Private

- (void)p_setupUI
{
    [self.buttonArray enumerateObjectsUsingBlock:^(UIButton * _Nonnull button,
                                                   NSUInteger idx,
                                                   BOOL * _Nonnull stop) {
        if (idx % 2 == 0) {
            [button setBackgroundImage:[[UIColor whiteColor] demo_imageWithColor] forState:UIControlStateNormal];
            [button setTitleColor:YAMTextDarkColor forState:UIControlStateNormal];
        } else {
            button.layer.borderColor = [UIColor demo_colorWithHex:@"#3f3f3f"].CGColor;
            [button setBackgroundImage:[YAMRedThemeColor demo_imageWithColor] forState:UIControlStateNormal];
            [button setBackgroundColor:[UIColor whiteColor]];
        }
        [self addSubview:button];
    }];
}

- (void)p_setupConstraints
{
    __block UIButton *lastButton = nil;
    [self.buttonArray enumerateObjectsUsingBlock:^(UIButton * _Nonnull button,
                                                   NSUInteger idx,
                                                   BOOL * _Nonnull stop) {
        if (!lastButton) {
            [button mas_makeConstraints:^(MASConstraintMaker *make) {
                make.top.bottom.left.equalTo(self);
            }];
        } else {
            [button mas_makeConstraints:^(MASConstraintMaker *make) {
                make.top.bottom.equalTo(self);
                make.left.equalTo(lastButton.mas_right).offset(10);
                make.width.equalTo(lastButton.mas_width);
            }];
        }
        if (idx == self.buttonArray.count - 1) {
            [button mas_updateConstraints:^(MASConstraintMaker *make) {
                make.right.equalTo(self);
            }];
        }
        lastButton = button;
    }];
}

@end
