//
//  OpenPlatformTwoLabelSettingTableViewCell.m
//  OpenSDKDemo
//
//  Created by Jiny.du on 2018/12/25.
//

#import "OpenPlatformDataItem.h"
#import "OpenPlatformTwoLabelTableViewCell.h"
#import "OpenPlatformUIDefine.h"

@interface OpenPlatformTwoLabelTableViewCell ()

@property (nonatomic, strong) UILabel *titleDisplayLabel;
@property (nonatomic, strong) OpenPlatformDataItem *item;
@property (nonatomic, strong) UILabel *subTitleDisplayLabel;
@property (nonatomic, strong) UIControl *tapControl;

@end

@implementation OpenPlatformTwoLabelTableViewCell

- (instancetype)initWithStyle:(UITableViewCellStyle)style reuseIdentifier:(NSString *)reuseIdentifier
{
    self = [super initWithStyle:style reuseIdentifier:reuseIdentifier];
    if (self) {
        [self commonInit];
    }

    return self;
}

- (void)commonInit
{
    self.separatorInset = UIEdgeInsetsMake(0, 20, 0, 0);
    self.backgroundColor = [UIColor clearColor];
    self.titleDisplayLabel = ({
        UILabel *label = [[UILabel alloc] init];
        label.font = [UIFont systemFontOfSize:14];
        label.numberOfLines = 1;
        label.textColor = [UIColor blackColor];
        [self.contentView addSubview:label];
        label;
    });
    self.subTitleDisplayLabel = ({
        UILabel *label = [[UILabel alloc] init];
        label.textAlignment = NSTextAlignmentRight;
        label.font = [UIFont systemFontOfSize:12];
        label.numberOfLines = 1;
        label.textColor = [UIColor demo_colorWithHex:@"#C7C7CD"];
        [self.contentView addSubview:label];
        label;
    });
    self.tapControl = ({
        UIControl *tapControl = [[UIControl alloc] init];
        [tapControl addTarget:self action:@selector(handlerAction) forControlEvents:UIControlEventTouchUpInside];
        self.tapControl.backgroundColor = [UIColor clearColor];
        [self addSubview:tapControl];
        tapControl;
    });
}

- (void)configWithSettingItem:(OpenPlatformDataItem *)item
{
    if (item.type != OpenPlatformItemTypeTwoLabel) {
        return;
    }

    self.item = item;
    self.titleDisplayLabel.text = self.item.titleString;
    self.subTitleDisplayLabel.text = self.item.descString;
    [self setNeedsLayout];
    [self layoutIfNeeded];
}

- (void)layoutSubviews
{
    [super layoutSubviews];
    [self.titleDisplayLabel sizeToFit];
    [self.subTitleDisplayLabel sizeToFit];

    self.titleDisplayLabel.frame = CGRectMake(8, (self.contentView.frame.size.height - self.titleDisplayLabel.frame.size.height)/2, self.titleDisplayLabel.frame.size.width, self.titleDisplayLabel.frame.size.height);

    self.subTitleDisplayLabel.width = MIN(self.contentView.width - self.titleDisplayLabel.maxX - 8, self.subTitleDisplayLabel.width);
    self.subTitleDisplayLabel.centerY = self.titleDisplayLabel.centerY;
    self.subTitleDisplayLabel.maxX = self.contentView.width - 8;
    self.tapControl.frame = self.bounds;
}

- (void)handlerAction
{
    !self.item.eventHandler?:self.item.eventHandler(self.item);
}

@end