//
//  OpenPlatformDataItem.m
//  OpenSDKDemo_Example
//
//  Created by Jiny.du on 2019/7/22.
//  Copyright © 2019 bytedance.co All rights reserved.
//

#import "OpenPlatformDataItem.h"

@implementation OpenPlatformDataItem

- (id)copyWithZone:(NSZone *)zone
{
    OpenPlatformDataItem *item = [[OpenPlatformDataItem allocWithZone:zone] init];
    item->_type = self->_type;
    item->_rightButtonTitle = self->_rightButtonTitle.copy;
    item->_placeholder = self->_placeholder.copy;
    item->_editText = self->_editText.copy;
    item->_titleString = self->_titleString.copy;
    item->_context = self->_context.copy;
    item->_descString = self->_descString.copy;
    item->_eventHandler = [self->_eventHandler copy];
    item->_tapRightButtonHandler = [self->_tapRightButtonHandler copy];
    return item;
}

- (CGFloat)heightForItem
{
    return 50.f;
}

- (NSString *)cellIdentify
{
    NSString *className = NSStringFromClass(self.class);
    NSString *typeName = @"";
    switch (self.type) {
        case OpenPlatformItemTypeNormal:
            typeName = @"Normal";
            break;
        case OpenPlatformItemTypeEdit:
            typeName = @"Edit";
            break;
        case OpenPlatformItemTypeTwoLabel:
            typeName = @"TwoLabel";
            break;
        case OpenPlatformItemTypeTapEdit:
            typeName = @"TapEdit";
            break;
        case OpenPlatformItemTypeSwitch:
            typeName = @"Switch";
            break;
    }
    return [className stringByAppendingString:typeName];
}

+ (instancetype)itemForSwitchWithTitle:(NSString *)title
                               context:(NSString *)context
                       defaultSwitchOn:(BOOL)isDefaultSwitchOn
                          eventHandler:(void (^)(OpenPlatformDataItem *item))eventHandler
{
    OpenPlatformDataItem *item = [[OpenPlatformDataItem alloc] init];
    item.type = OpenPlatformItemTypeSwitch;
    item.titleString = title;
    item.context = context;
    item.switchOn = isDefaultSwitchOn;
    item.eventHandler = eventHandler;
    return item;
}

+ (instancetype)itemForOneLabelWithTitle:(NSString *)title
                                 context:(NSString *)context
                            eventHandler:(void (^)(OpenPlatformDataItem *item))eventHandler
{
    OpenPlatformDataItem *item = [[OpenPlatformDataItem alloc] init];

    item.type = OpenPlatformItemTypeNormal;
    item.titleString = title;
    item.context = context;
    item.eventHandler = [eventHandler copy];
    return item;
}

+ (instancetype)itemForTwoLabelWithTitle:(NSString *)title
                              descString:(NSString *)descString
                                 context:(NSString *)context
                            eventHandler:(void (^)(OpenPlatformDataItem *item))eventHandler
{
    OpenPlatformDataItem *item = [[OpenPlatformDataItem alloc] init];

    item.type = OpenPlatformItemTypeTwoLabel;
    item.titleString = title;
    item.descString = descString;
    item.context = context;
    item.eventHandler = [eventHandler copy];
    return item;
}

+ (instancetype)itemForEditWithTitle:(NSString *)title
                             context:(NSString *)context
                           placehold:(NSString *)placehold
                        eventHandler:(void (^)(OpenPlatformDataItem *item))eventHandler
{
    OpenPlatformDataItem *item = [[OpenPlatformDataItem alloc] init];

    item.type = OpenPlatformItemTypeEdit;
    item.titleString = title;
    item.context = context;
    item.placeholder = placehold;
    item.eventHandler = [eventHandler copy];
    return item;
}

+ (instancetype)itemForEditAndBtnWithTitle:(NSString *)title
                                 placehold:(nullable NSString *)placehold
                                   context:(nullable NSString *)context
                                  btnTitle:(NSString *)btnTitle
                              eventHandler:(nullable void (^)(OpenPlatformDataItem *item))eventHandler
                               tapHandeler:(nullable void (^)(OpenPlatformDataItem *item))tapHandler
{
    OpenPlatformDataItem *item = [[OpenPlatformDataItem alloc] init];

    item.type = OpenPlatformItemTypeTapEdit;
    item.titleString = title;
    item.context = context;
    item.placeholder = placehold;
    item.rightButtonTitle = btnTitle;
    item.tapRightButtonHandler = [tapHandler copy];
    item.eventHandler = [eventHandler copy];
    return item;
}


+ (instancetype)itemForTwoLabelWithTitle:(NSString *)title
                                subTitle:(NSString *)subTitle
                                 context:(NSString *)context
                               placehold:(NSString *)placehold
                            eventHandler:(void (^)(OpenPlatformDataItem *item))eventHandler
{
    OpenPlatformDataItem *item = [[OpenPlatformDataItem alloc] init];

    item.type = OpenPlatformItemTypeTwoLabel;
    item.titleString = title;
    item.descString = subTitle;
    item.context = context;
    item.placeholder = placehold;
    item.eventHandler = [eventHandler copy];
    return item;
}

@end